import request from "./request.js"


// 获取首页数据
export function loadIndexs(data) {
	return request({
		url: '/api/index',
		method: 'get',
		data
	});
}

// 获取轮播图数据
export function banner(data) {
	return request({
		url: '/api/article/list/22',
		method: 'get',
		params: data
	});
}

// 获取科普文章列表
export function splist(data) {
	return request({
		url: '/api/article/list/1',
		method: 'get',
		params: data
	});
}
// 获取红会新闻文章列表
export function newsList(data) {
	return request({
		url: '/api/article/list/13',
		method: 'get',
		params: data
	});
}
// 获取信息公示文章列表
export function openList(data) {
	return request({
		url: '/api/article/list/19',
		method: 'get',
		params: data
	});
}
//获取政策法规文章列表
export function regulationList(data) {
	return request({
		url: '/api/article/list/17',
		method: 'get',
		params: data
	});
}
// 获取文章详情
export function details(data,id) {
	return request({
		url: '/api/article/details/'+id,
		method: 'get',
		data
	});
}
// 获取爱心捐款列表
export function loveList(data) {
	return request({
		url: '/api/bulletin',
		method: 'get',
		params: data
	});
}
//获取鄂州区新闻
export function ezqList(data) {
	return request({
		url: '/api/article/list/14',
		method: 'get',
		params: data
	});
}

//获取华容区新闻
export function hrqList(data) {
	return request({
		url: '/api/article/list/15',
		method: 'get',
		params: data
	});
}

//获取梁子湖区新闻
export function lzhqList(data) {
	return request({
		url: '/api/article/list/16',
		method: 'get',
		params: data
	});
}

//获取红会风采
export function redshow(data) {
	return request({
		url: '/api/article/list/20',
		method: 'get',
		params: data
	});
}

//获取友情链接
export function friendLink(data) {
	return request({
		url: '/api/article/list/21',
		method: 'get',
		params: data
	});
}
